@@ -1258,7 +1258,7 @@ class JAAQLModel(BaseJAAQLModel):
                 raise HttpStatusException(ERR__recipient_not_allowed)
             recipient_names = allowed_recipients[inputs[KEY__recipient]]
 
-        self.email_manager.construct_and_send_email(self.url, app_url, template, user_id, recipient_names, recipients, params,
+        self.email_manager.construct_and_send_email(self.url, app_url, template, user_id, recipient_names, recipients, {}, params,
                                                     attachments=EmailAttachment.deserialize_list(inputs[KEY__attachments], template[KEY__id]),
                                                     attachment_access_token=self.refresh(oauth_token))
 
@@ -1588,6 +1588,9 @@ class JAAQLModel(BaseJAAQLModel):
         if attach_as is None:
             attach_as = user_id
 
+        if public_application is not None:
+            attach_as = username
+
         self.add_node_authorization({
             KEY__node: NODE__host_node,
             KEY__role: attach_as,
@@ -1598,7 +1601,7 @@ class JAAQLModel(BaseJAAQLModel):
 
         if not attached:
             inputs = {
-                KEY__username: user_id,
+                KEY__username: username if public_application is not None else user_id,
                 KEY__password: db_password
             }
             execute_supplied_statement(self.jaaql_lookup_connection, QUERY__user_create_role, inputs)
